# hobo - portal to configure and deploy applications
# Copyright (C) 2015-2023  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.utils.translation import gettext_lazy as _

from . import models


class EditFullNameTemplateForm(forms.Form):
    user_full_name_template = forms.CharField(
        label=_('User full name template (Django)'),
        widget=forms.Textarea,
        required=False,
    )


class AttributeDefinitionCreateForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        if self.instance.name in ['first_name', 'last_name']:
            self.initial['searchable'] = True
            self.fields['searchable'].disabled = True
            self.fields['searchable'].help_text = _('"%s" field is always searchable.') % self.instance.name

    class Meta:
        model = models.AttributeDefinition
        fields = [
            'label',
            'name',
            'description',
            'required',
            'required_on_login',
            'asked_on_registration',
            'user_editable',
            'user_visible',
            'searchable',
            'disabled',
            'kind',
        ]


class AttributeDefinitionUpdateForm(AttributeDefinitionCreateForm):
    class Meta(AttributeDefinitionCreateForm.Meta):
        model = models.AttributeDefinition
        exclude = ['name', 'kind']
